@@ -8,13 +8,18 @@
 
 #include "flatpakreference.h"
 
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
 
-class KCMFlatpak : public KQuickAddons::ManagedConfigModule
+class KCMFlatpak : public KQuickManagedConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(FlatpakReferencesModel *refsModel MEMBER m_refsModel CONSTANT)
 public:
+    /**
+     * This KCM manages permissions for Flatpak application. It can open any
+     * installed application page directly: use @param args in the form of
+     * ["<ref>"], where <ref> is a FlatpakRef in formatted like "app/org.videolan.VLC/x86_64/stable".
+     */
     explicit KCMFlatpak(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
     Q_INVOKABLE bool isSaveNeeded() const override;
